/*
Button demo

This is a sample demo project for Olimexino-Nano (Leonardo) board
for button and orange LED on the board.

Simple demo which toggle LED (D17) triggered by the user button (HWB).

NOTE: LED is used as RX indicator for receiving data
so this pin is multiplexed with UART function.
If you try to control it as GPIO then UART won't work!!!
NOTE2: Since button isn't connected to any of the digital pins,
it can't be scanned as normal GPIO using the arduino function digitalRead.
The workarround is to make additional macros for it:
#define  BUT_OUTPUT  DDRE = DDRE & (~0x04)
#define  BUT_PORT    PORTE = PORTE | 0x04
#define  BUT_SCAN    (PINE & 0x04)

Build and hardware info:
Olimexino-Nano rev.A
Arduino IDE v1.0.5

Stanimir Petev, Olimex LTD
2014.02.12
*/

#define  BUTTON_MASK  (1<<2)                       // button is connected to E2
#define  BUT_OUTPUT  DDRE = DDRE & (~BUTTON_MASK)  // DDRE.2 --> 0 (input)
#define  BUT_PORT    PORTE = PORTE | BUTTON_MASK   // PORTE.2 --> 1 - when the pin is input this (output) register enable internal pull-up
#define  BUT_SCAN    (!!(PINE & BUTTON_MASK))      // scanning value of the E2 pin. Double inversion makes the result 0 or 1 instead of 0 or 1/2/4/8 etc.

#define  LED  17

void setup ()
{
  BUT_OUTPUT;  // button is set as output
  BUT_PORT;    // internal Pull-Up for PE.2 is enabled
  pinMode (LED, OUTPUT);  // LED is set output
}

void loop ()
{
  if (BUT_SCAN)               // if button is pressed
    digitalWrite (LED, LOW);  // turn off the LED
  else
    digitalWrite (LED, HIGH); // turn on the LED
}
